#
# spec file for package monit
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#               Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           monit
Version:        5.10
Release:        11.1
Summary:        Service Manager and Monitor System
License:        AGPL-3.0
Group:          System/Monitoring
Source:         http://mmonit.com/monit/dist/monit-%{version}.tar.gz
Source2:        http://mmonit.com/monit/dist/monit-%{version}.tar.gz.sha256
Source1:        monit-vendor-files.tar.gz
Patch1:         monit-better_default_monitrc.patch
Patch2:         monit-dirs.patch
Patch3:		monit-no_sslv3.patch
Source99:       monit-rpmlintrc
Url:            http://mmonit.com/monit/download/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
Obsoletes:      monit-beta < %{version}
Provides:       monit-beta = %{version}
%if "%{_vendor}" == "suse"
%define VENDOR SUSE
%else
%define VENDOR %_vendor
%endif

%description
Monit is a utility for managing and monitoring processes, files,
directories, and devices on a Unix system.  Monit conducts automatic
maintenance and repair and can execute meaningful causal actions in
error situations.  For example, monit can start a process if it does
not run, restart a process if it does not respond, and stop a process
if it uses too many resources.	You can use monit to monitor files,
directories, and devices for changes, such as time stamp changes,
checksum changes, or size changes. You can even use monit to monitor
remote hosts: monit can ping a remote host and check port connections.

%package doc
Summary:        Service Manager and Monitor System (Documentation and Examples)
Group:          System/Monitoring
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description doc
Monit is a utility for managing and monitoring processes, files,
directories, and devices on a Unix system.  Monit conducts automatic
maintenance and repair and can execute meaningful causal actions in
error situations.  For example, monit can start a process if it does
not run, restart a process if it does not respond, and stop a process
if it uses too many resources.	You can use monit to monitor files,
directories, and devices for changes, such as time stamp changes,
checksum changes, or size changes. You can even use monit to monitor
remote hosts: monit can ping a remote host and check port connections.

This package only contains the documentation and examples.
You must also install the package %{name} to actually use monit.

%prep
%setup -q -a1
%patch1 -p1
%patch2
%patch3
%__perl -n -e 'print $1,"\n" if /^\+{3}\s+(\S+)/' <"%PATCH2" \
| while read f; do
    %__perl -i -p -e '
s,\@\@PIDDIR\@\@,/run/monit,g;
s,\@\@EVENTDIR\@\@,/run/monit/events,g;
' "$f"
done

find doc/ -type f -size 0 -exec %__rm {} \;

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--with-ssl-lib-dir="%{_libdir}"

%__make %{?_smp_flags}

%install
%__make DESTDIR="%{buildroot}" install

%__install -d \
	"%{buildroot}/etc/init.d" \
	"%{buildroot}%{_sysconfdir}/monit.d" \
	"%{buildroot}%{_sbindir}" \
	"%{buildroot}%{_datadir}/monit" \
	"%{buildroot}%{_var}/adm/fillup-templates" \
	"%{buildroot}/run/monit" \
	"%{buildroot}/run/monit/events" \
	"%{buildroot}%{_var}/lib/monit"

. vendor-files/sysconfig/monit.tmpl
MONIT_BIN="%{_bindir}/monit"
MONIT_MODIFY_INITTAB="%{_datadir}/monit/monit-modifyinittab"
MONIT_PID_FILE="/run/monit/monit.pid"
MONIT_SYSCONFIG_FILE="/etc/sysconfig/monit"
MONIT_INITTAB_STATE_FILE="%{_var}/lib/monit/monit-inittab.state"
MONIT_ARGS="-p ${MONIT_PID_FILE} -s /run/monit/monit.state"
MONIT_EVENTQUE_DIR="%{_var}/lib/monit"
%__sed -e "s|%{_var}/monit|${MONIT_EVENTQUE_DIR}|g" \
	< monitrc > "%{buildroot}%{_sysconfdir}/monitrc"

pushd vendor-files
for templatefile in docu/README tools/monit-modifyinittab init/monit sysconfig/monit; do
	%__sed \
		-e "s|__MONIT_RC_FILE__|${MONIT_RC_FILE}|g" \
		-e "s|__MONIT_INITTAB_BASE__|${MONIT_INITTAB_BASE}|g" \
		-e "s|__MONIT_INITTAB_COMMENT__|${MONIT_INITTAB_COMMENT}|g" \
		-e "s|__MONIT_INITTAB_STATE_FILE__|${MONIT_INITTAB_STATE_FILE}|g" \
		-e "s|__MONIT_ARGS__|${MONIT_ARGS}|g" \
		-e "s|__MONIT_BIN__|${MONIT_BIN}|g" \
		-e "s|__MONIT_MODIFY_INITTAB__|${MONIT_MODIFY_INITTAB}|g" \
		-e "s|__MONIT_PID_FILE__|${MONIT_PID_FILE}|g" \
		-e "s|__MONIT_SYSCONFIG_FILE__|${MONIT_SYSCONFIG_FILE}|g" \
		< "${templatefile}.tmpl" \
		> "${templatefile}"
done
popd # vendor-files

%__install -m0754 vendor-files/init/monit "%{buildroot}/etc/init.d/monit"
%__ln_s ../../etc/init.d/monit "%{buildroot}/usr/sbin/rcmonit"
%__install -m0754 vendor-files/tools/monit-modifyinittab "%{buildroot}%{_datadir}/monit"
%__install -m0644 vendor-files/sysconfig/monit "%{buildroot}%{_var}/adm/fillup-templates/sysconfig.monit"
touch "%{buildroot}%{_var}/lib/monit/monit-inittab.state"
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1110
touch "%{buildroot}/run/monit/.monit.id"
touch "%{buildroot}/run/monit"/monit.{pid,state}
%endif
%__install -m0644 vendor-files/docu/README README.SUSE

%__install -d "%{buildroot}%{_docdir}/%{name}"
>doc.main.lst
for f in COPYING; do
    %__install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$f"
    echo "%doc %{_docdir}/%{name}/$f" >>doc.main.lst
done
>doc.doc.lst
for f in README* doc; do
    %__cp -a "$f" "%{buildroot}%{_docdir}/%{name}/"
    echo "%doc %{_docdir}/%{name}/$(basename $f)" >>doc.doc.lst
done

%post
%{fillup_and_insserv}
%__install -d -m0700 -o root -g root /run/monit
%__install -d -m0700 -o root -g root /run/monit/events

%preun
%{stop_on_removal monit}

%postun
%{restart_on_update monit}
%{insserv_cleanup}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -f doc.main.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/monitrc
%dir %{_sysconfdir}/monit.d
%attr(0754,root,root) %config /etc/init.d/monit
/usr/sbin/rcmonit
%{_bindir}/monit
%dir %{_datadir}/monit
%{_datadir}/monit/monit-modifyinittab
%{_var}/adm/fillup-templates/sysconfig.monit
%dir %{_var}/lib/monit
%ghost %{_var}/lib/monit/monit-inittab.state
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1110
%ghost %dir /run/monit
%ghost /run/monit/monit.pid
%ghost /run/monit/monit.state
%ghost /run/monit/.monit.id
%ghost %dir /run/monit/events
%endif
%doc %{_mandir}/man1/monit.1%{ext_man}

%files doc -f doc.doc.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}

%changelog
* Mon Jun  6 2016 jmutkawoa@gmail.com
- disable sslv3 according to RFC7568 (boo#974763)
  monit-no_sslv3.patch
* Fri Mar 18 2016 jgleissner@suse.com
- fixed pid file directory (bnc#971647)
- updated monit-better_default_monitrc.patch to set pid file
  directory in /etc/monitrc
- removed /run from file list
* Sat Nov 29 2014 lmuelle@suse.com
- update to 5.10:
  + New: Redis protocol test added.
  + New: MongoDB protocol test added.
  + New: Changes due to vulnerabilities in SSLv2 and SSLv3.
    See CVE-2014-3566 aka "POODLE".
  + Fixed: Issue #101: Manual-mode monitored services state may not be restored
    if the monitoring state was changed by user right before the system died.
  + Fixed: Issue #104: Keep umask Monit was started with when executing
    start/stop/restart programs, check programs and creating files.
  + Fixed: Issue #107: Support multi-line response in the LMTP protocol test.
  + Fixed: Support TLSv1.1 and TLSv1.2 when FIPS is enabled.
- update to 5.9:
  + New: Output from your check program script is now displayed in Monit’s UI.
  + New: Aggregate and use human friendly units for memory, swap and space
    usage values in the User Interface.
  + New: Support monitoring of filesystems by generic device strings such as
    sshfs on Linux or ZFS filesystems on Solaris.
  + New: You can now send HTTP headers with the HTTP protocol test.
  + New: Program check now supports exit status change monitoring.
  + New: Added option to run check program as a different user and/or group.
  + New: Changed name of ICMP ECHO statement to Ping which is the more common
    name used for a network ping.
  + New: Simplified HTTP and SMTP protocol test with SSL.
  + Fixed: Issue #59, Issue #88: Some systems with upstart (e.g. RHEL/CentOS)
    had problems with Monit's restart action which consists of a
    stop/start sequence.
  + Fixed: Issue #54: MySQL protocol test.
  + Fixed: Issue #64: Resets counter once a service has successfully restarted
  + New: Issue #84. You can now test for '\0' in an expect string.
  + Fixed: Issue #55: Only run cron style checks once per minute.
  + Fixed: Issue #78: Include open slots in Apache status check calculations
  + Fixed: Issue #57: Inode usage check and space usage check now show correct
    result for large filesystems on 32-bit platforms.
  + Fixed: Issue #70: Removed newline in Monit's $ENV strings
  + Fixed: Issue #72: Monit no longer requires a start, stop or restart
    program defined for a check.
  + Fixed: P.R. #17: Bug fix, missing "check file" target files result in error
    "Invalid checksum" sha1 has a string length of 40.
  + Fixed: P.R. #18: Add missing space in the timeout text in UI.
  + Fixed: Issue #71: Subtract SLAB reclaimable memory from the system memory
    usage on Linux
  + Fixed: Support TLSv1.1 and TLSv1.2 in "set mailserver"
  + Fixed: Sporadic "PPID changed from 0 to ..." alert after process restart
  + Fixed: PID/PPID changed events were sometimes triggered after program
    restart
  + Fixed: Linux: filesystem space usage on some network based filesystems
    such as sshfs
  + Fixed: Automatically reload Monit if ID was reset using --resetid CLI
    option.
  + Fixed: Improved speed of send/expect protocol test
  + Fixed: Fixed SMTP protocol test to check the response code
* Sat Nov 29 2014 lmuelle@suse.com
- Remove /var from path in rpmlintrc of the .monit.id file.
- Package /run only on post-11.1 systems.
* Sat Nov 29 2014 lmuelle@suse.com
- Modify shebang to point to bash where bash is required in
  vendor-files/tools/monit-modifyinittab.tmpl
- Align used SUSE trade name in the vendor-files.
* Wed Jul 30 2014 sfalken@opensuse.org
- update to 5.8.1:
  * Changed all /var/run to /run to fix rpmlint check failure in Factory
  * Added: monit-5.8.1.tar.gz
  * Deleted: monit-5.6.tar.gz
    monit-page_shift.patch as new version deprecates it
  * Updated: monit-better_default_monitrc.patch
* Wed Sep  4 2013 pascal.bleser@opensuse.org
- update to 5.6:
  * SMTP AUTH LOGIN support added (MS Exchange SMTP authentication should now
    work)
  * favicon.ico added to the HTTP interface
  * Bugfixes:
  - If an undefined checksum test was used and the file did not exist on
    Monit start, Monit would return an error
  - If the configuration file ended with a comment but with no trailing LF
    character, Monit would return syntax error
  - If a service timed out after too many restarts and alert was used as the
    action, then the Timeout flag remained set even if the service recovered
  - Escape mail messages properly for sending via SMTP
  - Escape XML messages properly
* Wed Jun  5 2013 lars@samba.org
- update to 5.5.1:
  * Info and debug messages are no longer sent to stderr, only to stdout.
  * Improved output from 'check program', If the program returns an error
    message, include only that message in alert $DESCRIPTION so users can
    compose their own alert format. If program provided no output on
    error, use a default message.
  * Improved "check system", $HOST can now be used as a service name.
    $HOST will expand to the system hostname. Example: check system $HOST
  * Fixed "Unable to read magic" which was reported on first Monit start.
* Tue Mar 12 2013 poelzleithner@b1-systems.de
- use relative path for dirname in init script. dirname is not
  longer in /bin, therefor the init script is broken
* Sun Nov  4 2012 lars@samba.org
- update to 5.5:
  * check program:
  - Multiple exit values can be tested within single program check
  - Exit value test supports multiple cycles option ("for X cycles")
  - If exit value test matches and the stderr has no data, try stdout
  * Renamed mail header (message-id and mime-version) to prevent
    triggering spam check of capitalization.
  * The 'check system <name>' statement sets the system hostname in mail
    alerts and initial hostname in M/Monit.
  * Increase the default mailserver timeout to 30 seconds.
  * Fix the rare hung on linux which may occur during program execution.
  * In the case that the process start/restart execution failed, monit kept
    "Execution failed" flag even if the process was recovered later (for
    example it was starting slowly or manually recovered).
  * Fix the mail alert (strict SMTP implementation) to pass MTA-side sanity
    checks like postscreen.
  * The -t option tests the configuration file syntax even if the
    file permissions are wrong.
  * Do not display the default non-existence test for the check
    program (not applicable in the check program context).
* Fri May 18 2012 lars@samba.org
- update to 5.4:
  * New process uptime test added.
  * The monit hostname will fallback to plain machine's hostname if the lookup
    for FQDN hostname didn't found matching entry.
  * The CPU usage for multi-threaded processes on multi-core machine was
    reported incorrectly in the case that the process used more CPU resources
    then equivalent to one core.
  * The content match test now sends one event per cycle and pattern.
  * The /proc/ files content match test was skipped, as the file size on the
    procfs is 0, so monit supposed that there is no content to read.
  * Allow reading status and perform Monit actions when using client SSL
    certificate.
  * When the process is starting/stopping, do the process state check more
    effectively to not stress the low power devices with aggresive polling.
  * Make the process start/stop wait resistant to large time changes.
  * Compilation: If PAM is enabled but the PAM headers or library are not
    found by the configure script, it will report error.
- BuildRequire pam-devel.
* Tue Mar  6 2012 cfarrell@suse.com
- license update: AGPL-3.0
  My mistake - there is no entry for AGPL-3.0+ on spdx.org/licenses. The
  only available one is AGPL-3.0 (without the plus)
* Wed Feb 29 2012 cfarrell@suse.com
- license update: AGPL-3.0+
  monit is AGPL-3.0 _not_ GPL-3.0
* Wed Jan 25 2012 pascal.bleser@opensuse.org
- fix bnc#743289 by adding monit-dirs.patch to set the PIDDIR accordingly to
  what is preset in the monitrc configuration (and in the spec file), as well
  as to fix the default event directory
* Wed Dec 21 2011 pascal.bleser@opensuse.org
- update to 5.3.2:
  * fix bug #34801: the file content match test did reset of the read position
    in the case that the unmonitor or stop action was done. When the file
    monitoring was enabled again, the content match test was applied to the
    content which was tested already.
  * log error details in the case that the name resolving failed
  * fix the system cpu usage statistics when pattern based process check is
    used and the service is restarted
  * Debian Bug#652715: "include files not found" warning: do not display the
    warning if the include directory is empty
- create /var/run/monit in the init script on start (if needed), as /var/run is
  on a volatile filesystem (tmpfs) since 12.1
* Tue Dec 13 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- fixes to init script and configuration file for state file
- fix installation routine on >= 12.1: directories under /var/run are now
  created at installation time, as /var/run is on tmpfs on >= 12.1
- minor packaging improvements, including the use of the pristine upstream
  tarball instead of a recompressed one (better traceability)
* Fri Nov  4 2011 pascal.bleser@opensuse.org
- add some better defaults:
  * set mailserver to localhost
  * set alert recipient to root@localhost
  * enable event queue in /var/run/monit/events
  * move id and state files to /var/run/monit/
* Tue Oct 25 2011 pascal.bleser@opensuse.org
- update to 5.3.1:
  * log the particular connection attempt failure in debug mode when the retry
    is enabled
  * Monit can deliver events and status to independent M/Monit instances if
    multiple mmonit URLs are set
  * fixed: the ICMP echo (ping) test may report false positive error if the
    machine where Monit is running has heavy ICMP traffic generated by other
    applications
  * fixed: the file content match test will be performed even on the existing
    content when Monit starts; the last position is saved to the statefile, so
    monit won't generate alert after restart; note that when you start the
    monit 5.3.1 the first time, it can do actions for content match which was
    handled by previous monit version already as the previous monit versions
    didn't saved the position
  * make the monitoring state persistent for manual mode services
  * display the memory usage total %% in the status overview; the memory usage
    in kB displayed the total already, so the percentage didn't match
  * fix the HTML overview page alignment in the Internet Explorer
  * fix sporadic SSL routines:func(169):reason(161) errors
  * if MySQL protocol test failed, report the correct MySQL error code
- changes from 5.3.0:
  * new 'check program' statement added: allows to check the exit status of an
    external program or script from Monit
  * added crontab style support for individual services; you can now specify
    when an individual service should run its checks (or not run)
  * connection retry option added: allows to retry a network connection in the
    same testing cycle before reporting an error
  * detailed protocol connection errors are now included in alerts
  * the HTML overview page displays the CPU and memory total now (including
    children), so real service related usage is displayed also for services
    which spawn worker processes, such as Apache or Spamassassin
  * HTML view improvements
  * fix MySQL protocol test: MySQL 5.5.12 returns new error code in the case of
    authentication failure
  * the stacktrace logging on error is disabled in -v (verbose) mode as it was
    too verbose for common service debugging tasks, it can be enabled using -vv
    option
  * improve how fast Monit check if a program was started or stopped
  * fix the monitoring state presentation during service restart which
    temporarily displayed "Not monitored", whereas the monitoring was enabled
  * the "data collected" is updated only if the check was not skipped
* Tue Mar 29 2011 pascal.bleser@opensuse.org
- update to 5.2.5:
  * fix process match check - when the monitored process failed and was
    restarted by Monit, Monit didn't recognized it is running after the restart
    and reported  start failure (similar on stop)
  * fix Debian #617259: symbolic links in the filesystem check doesn't work
  * fix Debian bug #614984: smtp protocol test issues both EHLO and HELO
  * fix bug #32583: multiple SIP OPTIONS messages use the same header data
  * try harder to get FQDN hostname for the host where monit is running; the
    hostname in the $HOST variable which is used in the mail sender may thus
    change
  * support symbolic link to monit configuration file
  * fix crash when monit daemon start delay option was used and monit was
    signalized to stop before the start delay passed
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Tue Feb 22 2011 pascal.bleser@opensuse.org
- update to 5.2.4:
  * added the "procmatch" CLI command which allows for easy testing of pattern
    for process match check
  * set the default log file mask to 0640 (originally it was 0664)
  * reduced monit memory footprint by ca. 10%%.
  * fix memory usage monitoring in OpenVZ VPS 2.6.32 virtual hosts
  * if the protocol test failed, show the request in the event
  * randomize the mail message id to prevent duplicates in the case, that the
    same hostname is used on multiple hosts running monit and messages are
    generated in the same second in parallel
* Thu Sep 23 2010 pascal.bleser@opensuse.org
- fixed typo in init script, "description" -> "Description"
- added missing dependency on $remote_fs in init script
- dropped monit-no_strip.patch, as upstream doesn't forcibly strip symbols any more
- /var/run/monit is now created at runtime, in order to work properly if /var/run is on tmpfs
- documentation split out into -doc subpackage
- update to 5.2:
  + new features:
  * added support for monitoring processes without pidfile using pattern matching
  * added support for swap monitoring
  * allow to override the default action when service doesn't exist
  * Monit automatically registers credentials with M/Monit now, so it's not necessary to set it manually in M/Monit anymore
  * added memcache protocol test
  * added openssl FIPS to Monit httpd
  * the 'check system' can now use start/stop program statements too
  * added the option to set the "Reply-To" mail header in mail-format
  * display backtrace on error if debug mode is enabled (requires backtrace support in libc)
  + bugfixes:
  * show real process uptime - formerly the presented uptime was based on create and modify timestamp of process' pidfile which provides invalid uptime if the pidfile is replaced and process keeps running with original PID
  * when user triggered action for some service (such as stop) and before that action completed user triggered another action for the same service (such as start), the second action has been ignored. Monit will not accept new action and return temporary error until the previous action completed
  * if process resource usage gathering failed, retry next cycle as the error can be temporary
  * fixed sporadic failures when SSL was used
  * ICMP echo test (ping):
  - fixed sporadic false positive/negative
  - removed limit of 20 pings per cycle
  * DNS test:
  - accept NS root request refusal as correct response because server reacts on request
  - accept authority answer as alternative to record
  * RADIUS test fix
  * M/Monit heartbeat is fully independent of testing cycle now to prevent false positive when service test blocks
  * fixed SMTP STARTTLS protocol, required for servers that adhere strictly to RFC 3207 4.2
  * service name:
  - allow the service name to start with "/"
  - fixed handling of the service names which contain "/" in the name in Monit web interface
  * when 'check system' is not defined, monit adds it automatically using hostname for service name
  * remove extra NL characters from message when resource succeeded event is sent
  * fixed display of cpu user/system/wait usage which temporarily displayed -1.0%% between two monitoring cycles while cpu monitoring was initializing
  * fixed display of port response time as -1 if 'monit status' was called in the middle of service test
  * fixed display of service initializing state after monit start or reload
  * fixed MONIT_DESCRIPTION environment variable
* Tue Aug 10 2010 lmuelle@suse.de
- Remove merged superfluous hz patch.
* Tue Aug 10 2010 lmuelle@suse.de
- Add Should-Start $syslog $time $named to the init script; (bnc#553082).
* Tue Feb 23 2010 pascal.bleser@opensuse.org
- update to 5.1.1:
  * several more protocol tests and bugfixes were added
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 5.0.3
* Thu Apr 16 2009 pascal.bleser@opensuse.org
- update to 5.0
* Fri Nov  9 2007 crrodriguez@suse.de
- update to version 4.10.1 (massive feature,bugfix release see CHANGES.txt for more details)
- add missing PreReq tags to fix build in BETA
- add missing remote_fs dependency in the init script
* Tue Nov  6 2007 guru@unixtech.be
- update to 4.10
* Thu Sep 20 2007 guru@unixtech.be
- moved to openSUSE Build Service
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Sat Mar 24 2007 guru@unixtech.be
- new package, based on SUSE/Factory's monit source RPM (2007-03-24)
* Mon Aug  7 2006 ro@suse.de
- define HZ sysconf(_SC_CLK_TCK) if not defined
* Sat May 27 2006 lmuelle@suse.de
- Update to version 4.8.1 (bugfix release; see CHANGES.txt for more details).
  * Fix logging on 64-bit systems.
  * Don't stop if there is no space on the filesystem.
  * Remove the false warning about TOTALMEMORY.
* Fri Apr 21 2006 lmuelle@suse.de
- Use /var/lib/monit to store the inittab state file.
* Tue Apr 18 2006 lmuelle@suse.de
- Use kill instead of killproc to terminate monit if we start monit from
  inittab.
- Add /etc/monit.d and /var/lib/monit directories.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jan 13 2006 lmuelle@suse.de
- Update to version 4.7.
* Thu Oct 27 2005 lmuelle@suse.de
- Update to version 4.6.
* Thu Apr 14 2005 lmuelle@suse.de
- Update to version 4.5.1.
* Mon Apr 11 2005 lmuelle@suse.de
- Update to version 4.5.
* Mon Oct 11 2004 lmuelle@suse.de
- Update to version 4.4.
* Fri Sep 10 2004 lmuelle@suse.de
- Remove update notify message, [#44356].
- Move vendor files to an own tar ball.
* Fri May 14 2004 lmuelle@suse.de
- Update to version 4.3.
* Tue Apr 20 2004 lmuelle@suse.de
- Update to version 4.2.1, [#39166]
* Wed Jan  7 2004 lmuelle@suse.de
- update to version 4.1.1
- allow call of /usr/share/monit/monit-modifyinittab without a switch
- add /usr/share/monit/monit-modifyinittab as Command: to sysconfig file
* Mon Nov 10 2003 lmuelle@suse.de
- rename SuSEconfig.monit to /usr/share/monit/monit-modifyinittab
- add --add and --remove switch to /usr/share/monit/monit-modifyinittab
- call /usr/share/monit/monit-modifyinittab in the init script if
  MONIT_VIA_INITTAB of /etc/sysconfig/monit is set to "yes"
* Sat Nov  8 2003 lmuelle@suse.de
- use 0600 for /etc/monitrc
- add systax check to init and SuSEconfog.monit script
- don't check for configuration file or syntax if the init script is called
  with 'stop'
* Fri Nov  7 2003 lmuelle@suse.de
- update to version 4.1
- add restart on update and other usual macros to %%preun and %%postun
- add poll option to the init script to send SIGUSR1
- add a vendor README
- add norootforbuild to the spec file
* Wed Oct  1 2003 schwab@suse.de
- Don't use PAGE_SHIFT.
* Mon Jun  2 2003 lmuelle@suse.de
- inital SuSE RPM based on the spec file provided by the monit team
